+++
title   = 'Skynet Account Recovery'
date    = 2024-12-27
slug    = 'recovery'
+++

## Jan 2023 Downtime & Account Recovery
In Jan 2023 we had extended downtime, for more information checkout [this link][0].  
The next section will outline the changes that have been made in the last year while the subsequent one will deal with Account Recovery.

[0]: https://public.skynet.ie/postmortem/2023-01-12_Loss-of-network-access.html

### Service Changes
As a result of the upgrade/migration/downtime there have been several changes to services.  
Some of these are due to security requirements, others are due to some old software being difficult to source, some are because we have worked with UL Wolves to create a new API to automate many processes.

#### Additions
* Account self management page: [https://account.skynet.ie][account]  
  This allows new members to sign up, existing members to change account details (password, contact email, ssh keys), and for password resets.
* [https://gitlab.skynet.ie][2]    
  Our own Gitlab instance with runners, the cluster config and pipelines are [here][3].  
  User: ``$username``  
  Pass: ``$password``  
* [https://nextcloud.skynet.ie/][4]   
  A replacement for Google Drive, has Open Office, maps and a good email suite.  
  User: ``$username`` or ``$username@skynet.ie``  
  Pass: ``$password``  
* A [Discord Bot][5] to manage the roles of members in our [Discord][discord]

[account]: https://account.skynet.ie
[2]: https://gitlab.skynet.ie
[3]: https://gitlab.skynet.ie/compsoc1/skynet/nixos
[4]: https://nextcloud.skynet.ie
[5]: https://gitlab.skynet.ie/compsoc1/skynet/discord-bot
[discord]: https://discord.skynet.ie

#### Changes
* Usernames have been converted to comply with modern linux standards.  
  Usernames with uppercase have been converted to lowercase.  
  Usernames starting with a number have been prefixed by a ``_``  
* ``UserName`` is now ``username``
* ``0username`` is now ``_0username``
* Webmail is now available at [https://mail.skynet.ie][7]  
  Still roundcube which should be familiar.  
  User: ``$username@skynet.ie``  
  Pass: ``$password``  
* For Thunderbird use these:  
  User: ``$username@skynet.ie``   
  Pass: ``$password``  
* SSH now requires an ssh key (can be set in the account page above)
* SSH access is now on ``skynet.skynet.ie``
* Personal sites are now accessible as ``$username.users.skynet.ie`` (new format) as opposed to ``skynet.ie/~$username`` (old format)  
  Any old format links will redirect to the new format for compatability.    
  This gives us separation from the core Skynet site.    
* Old home data can be found in ``/skynet_old/home/$username``
* Old emails (prior to 2023-01-12) can be found in the ``skynet_old`` folder in your mail account.

[7]: https://mail.skynet.ie

#### Email Aliases
* We are currently working on associating aliases with the Skynet account they are for.
* This creates a separate mail account that shares the same password as the base Skynet account.
* If you believe an alias is missing please get in contact with us (Details are below)
* Currently, no new aliases are planned, but this may change in the future.

#### Removals
* Lifetime and 10 year memberships ceased to exist in 2019.
* Email terminal clients are no longer available.

### Account Recovery
<p class="p1">
  <!-- this is in html in order to have the yellow colour highlighting-->
  Reminder:
  <br />
  To hold a Skynet account you must be a current member of the UL Computer society.
  <br/>
  This is done through UL Wolves (<a href="https://ulwolves.ie" target="_blank" rel="noopener">https://ulwolves.ie</a>).
  <br/>
  There are no exceptions to this.
</p>

There are 5 possible workflows for getting back up and running again:
* You know your Skynet ``user/pass`` and your UL Wolves ``user/pass``.
* You know your Skynet ``user/pass`` but not your UL Wolves ``user/pass``.
* You know your Skynet ``user/pass`` but do not have a UL Wolves account.
* You know your UL Wolves ``user/pass`` but not your Skynet ``user/pass``.
* You do not know your Skynet ``user/pass`` and your UL Wolves ``user/pass``.

#### You do not know your UL Wolves ``user/pass``
* If you signed up with a non UL/Skynet account there is a password reset process: [https://ulwolves.ie/login/help][8]
* If you forgot your UL Wolves username Contact Us (see below) and we may be able to inform you what username(s) you had used.
* If you forgot your UL Wolves password and your UL Wolves username was a ``@skynet.ie`` email then follow steps below to create a new account.

[8]: https://ulwolves.ie/login/help

#### You do not have a UL Wolves account.
* Follow steps 1-6 on [https://renew.skynet.ie][renew]

[renew]: https://renew.skynet.ie

#### You know your UL Wolves ``user/pass``
* On our Society page ([https://ulwolves.ie/society/computer][wolves]) Request Membership  
  (steps 7-8 on [https://renew.skynet.ie][renew])  
* Either pay €10 for 1 year online (we can approve instantly once we see the request).  
  Or pay €40 for 5 years following steps 9-11 on [https://renew.skynet.ie][renew].  
  (May take a little while to verify with the bank account.)
* Go to the account page: [https://ulwolves.ie/memberships/profile][wolves_profile]
* For the ``Preferred Contact Email`` set a <b>NON-Skynet</b> Email

[wolves]: https://ulwolves.ie/society/computer
[wolves_profile]: https://ulwolves.ie/memberships/profile

#### You know your Skynet ``user/pass``
* Go to [https://account.skynet.ie/modify][account_modify]
* Set the ``Email`` to be the ``Preferred Contact Email`` from wolves
* If you want to ssh in also set an ssh key.

[account_modify]: https://account.skynet.ie/modify

#### You do not know your Skynet ``user/pass``
* Get in contact with us and we will see what we can do.  
  We have a few methods that may be able to link your Skynet account with an address you currently possess.  

#### Contact us
* Email: ``compsoc[at]skynet.ie``
* Discord: ping @committee on [our discord][discord] (there is a ``#help-and-support`` channel).
